# creditscoring

creditscoring is a Python package built as a credit scoring toolkit.

<table>
<tr>
<td>Supports</td>
<td>Python 3.6,3.7
</tr>
<tr>
<td>Latest Release</td>
<td>
  <a href="https://pypi.org/project/credit-scoring-toolkit/">
    <img src="https://img.shields.io/pypi/v/credit-scoring-toolkit.svg" alt="latest release" />
  </a>
</td>
</tr>
<tr>
<td>Package Status</td>
<td>
  <a href="https://pypi.org/project/credit-scoring-toolkit/">
    <img src="https://img.shields.io/pypi/status/credit-scoring-toolkit.svg" alt="latest release" />
  </a>
</td>
</tr>
<tr>
<td>License</td>
<td>
  <a href="https://github.com/Keris/creditscoring/blob/master/LICENSE">
    <img src="https://img.shields.io/pypi/l/credit-scoring-toolkit.svg" alt="license" />
  </a>
</td>
</tr>
</table>

## Installation

### Requirements

To use creditscoring the following packages are required:

- pandas >= 0.20.1
- numpy >= 0.7.0
- matplotlib >= 1.1
- seaborn >= 0.8.0
- scipy >= 0.10.0
- scikit-learn >= 0.18

Development and testing additionally require:

- pytest
- coverage
- flake8
- twine

### Install latest release version via pip

```bash
pip install credit-scoring-toolkit
```

### Install latest development version

```bash
pip install git+https://github.com/Keris/creditscoring.git
```
or
```bash
git clone https://github.com/Keris/creditscoring.git
python setup.py install
```